<?php

function spark_news_section_setup( $wp_customize ) {

  $wp_customize->add_section( 'spark_news_single_options',
   array(
      'title'       => __( 'Single Page Settings', 'spark-news' ), //Visible title of section
      'priority'    => 20, //Determines what order this appears in
      'capability'  => 'edit_theme_options', //Capability needed to tweak
   )
  );


    $wp_customize->add_setting( 'spark_news_single_page_image_setting', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
     array(
        'default'    => 'right-sidebar', //Default setting/value to save
        'type'       => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
        'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
        'sanitize_callback' => 'spark_news_sanitize_select',
     )
    );

    $wp_customize->add_control( new WP_Customize_Control(
     $wp_customize, //Pass the $wp_customize object (required)
     'spark_news_single_page_image_control', //Set a unique ID for the control
     array(
        'label'      => __( 'Single Post Featured Image', 'spark-news' ), //Admin-visible name of the control
        'settings'   => 'spark_news_single_page_image_setting', //Which setting to load and manipulate (serialized is okay)
        'priority'   => 10, //Determines the order this control appears in for the specified section
        'section'    => 'spark_news_single_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
        'type'    => 'select',
        'choices' => array(
            'right-sidebar' => 'Right sidebar',
            'left-sidebar' => 'Left sidebar',
            'no-sidebar' => 'no-sidebar',
        ),
    )
    ) );
}

add_action( 'customize_register', 'spark_news_section_setup');


function spark_news_accent_color_setup( $wp_customize ) {

  /******************************** Primary Color *****************************/
    $wp_customize->add_setting( 'spark_news_primary_color_setting', array(
      'default'   => '#f6727f',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'spark_news_primary_color_control', array(
      'section' => 'colors',
      'label'   => esc_html__( 'Primary color', 'spark-news' ),
      'description' => __( 'To change the each category colors, goto Posts -> Categories and click on edit to set/change color of an existing category.', 'spark-news' ),
      'settings'      =>  'spark_news_primary_color_setting',
    ) ) );
}

add_action( 'customize_register', 'spark_news_accent_color_setup');




function spark_news_blog_section_setup( $wp_customize ) {

  $wp_customize->add_panel( 'spark_homepage_panel_id', array(
    'priority'       => 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => 'Homepage',
    'description'    => '',
  ) );

  $wp_customize->add_section( 'spark_options',
   array(
      'title'       => __( 'Homepage Setup', 'spark-news' ), //Visible title of section
      'panel'       => 'spark_homepage_panel_id',
      'priority'    => 20, //Determines what order this appears in
      'capability'  => 'edit_theme_options', //Capability needed to tweak
   )
  );


  /******************************** Big Category *****************************/
  // Credits: https://blog.josemcastaneda.com/2015/05/13/customizer-dropdown-category-selection/
  // create an empty array
  $cats = array();

  // we loop over the categories and set the names and
  // labels we need
  foreach ( get_categories() as $categories => $category ){
    $cats[$category->term_id] = $category->name;
  }

    $wp_customize->add_setting( 'spark_grid_section_category_setting', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
     array(
        'default'    => '1', //Default setting/value to save
        'type'       => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
        'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
        'sanitize_callback' => 'absint',
     )
    );
    $wp_customize->add_control( new WP_Customize_Control(
     $wp_customize, //Pass the $wp_customize object (required)
     'spark_grid_section_category_control', //Set a unique ID for the control
     array(
        'label'      => __( 'Grid Section Category', 'spark-news' ), //Admin-visible name of the control
        'settings'   => 'spark_grid_section_category_setting', //Which setting to load and manipulate (serialized is okay)
        'priority'   => 10, //Determines the order this control appears in for the specified section
        'section'    => 'spark_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
        'type'    => 'select',
        'choices' => $cats,
    )
    ) );

  $wp_customize->add_setting( 'spark_top_section_category_setting', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
     array(
        'default'    => '1', //Default setting/value to save
        'type'       => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
        'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
        'sanitize_callback' => 'absint',
     )
    );
    $wp_customize->add_control( new WP_Customize_Control(
     $wp_customize, //Pass the $wp_customize object (required)
     'spark_top_section_category_control', //Set a unique ID for the control
     array(
        'label'      => __( 'Top Section Category', 'spark-news' ), //Admin-visible name of the control
        'settings'   => 'spark_top_section_category_setting', //Which setting to load and manipulate (serialized is okay)
        'priority'   => 10, //Determines the order this control appears in for the specified section
        'section'    => 'spark_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
        'type'    => 'select',
        'choices' => $cats,
    )
    ) );

    $wp_customize->add_setting( 'spark_top_list_section_category_setting', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
     array(
        'default'    => '1', //Default setting/value to save
        'type'       => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
        'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
        'sanitize_callback' => 'absint',
     )
    );
    $wp_customize->add_control( new WP_Customize_Control(
     $wp_customize, //Pass the $wp_customize object (required)
     'spark_top_list_section_category_control', //Set a unique ID for the control
     array(
        'label'      => __( 'Top Section list Category', 'spark-news' ), //Admin-visible name of the control
        'settings'   => 'spark_top_list_section_category_setting', //Which setting to load and manipulate (serialized is okay)
        'priority'   => 10, //Determines the order this control appears in for the specified section
        'section'    => 'spark_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
        'type'    => 'select',
        'choices' => $cats,
    )
    ) );

    $wp_customize->add_setting( 'spark_grid_section_category_setting', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
     array(
        'default'    => '1', //Default setting/value to save
        'type'       => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
        'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
        'sanitize_callback' => 'absint',
     )
    );
    $wp_customize->add_control( new WP_Customize_Control(
     $wp_customize, //Pass the $wp_customize object (required)
     'spark_grid_section_category_control', //Set a unique ID for the control
     array(
        'label'      => __( 'Grid Section Category', 'spark-news' ), //Admin-visible name of the control
        'settings'   => 'spark_grid_section_category_setting', //Which setting to load and manipulate (serialized is okay)
        'priority'   => 10, //Determines the order this control appears in for the specified section
        'section'    => 'spark_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
        'type'    => 'select',
        'choices' => $cats,
    )
    ) );

}

add_action( 'customize_register', 'spark_news_blog_section_setup');
